@@ -10,14 +10,6 @@
 
 // UNSUPPORTED: c++98, c++03, c++11, c++14
 
-// The following compilers don't consider a type an aggregate type (and
-// consequently not a literal type) if it has a base class at all.
-// In C++17, an aggregate type is allowed to have a base class if it's not
-// virtual, private, nor protected (e.g. ConstexprTestTypes:::NoCtors).
-// XFAIL: gcc-5, gcc-6
-// XFAIL: clang-3.5, clang-3.6, clang-3.7, clang-3.8
-// XFAIL: apple-clang-6, apple-clang-7, apple-clang-8.0
-
 // <variant>
 
 // template <class ...Types> class variant;
@@ -33,12 +25,18 @@
 #include "test_macros.h"
 #include "variant_test_helpers.hpp"
 
+
 int main() {
   {
-    using V = std::variant<int, ConstexprTestTypes::NoCtors>;
+    using V = std::variant<int, long>;
     constexpr V v;
     static_assert(v.index() == 0, "");
   }
+  {
+    using V = std::variant<int, long>;
+    V v;
+    assert(v.index() == 0);
+  }
   {
     using V = std::variant<int, long>;
     constexpr V v(std::in_place_index<1>);
